##  Prerequisites
Before you start, install [NodeJS LTS![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fnodejs.org%2Fen%2F "https://nodejs.org/en/") on your system.
This tutorial assumes you have basic knowledge of:
  * [LeanIX Reporting Library![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fgithub.com%2Fleanix%2Fleanix-reporting "https://github.com/leanix/leanix-reporting")
  * [Reports in SAP LeanIX](https://help.sap.com/docs/leanix/ea/reports?locale=en-US&state=PRODUCTION&version=CLOUD)
  * [JavaScript (ES6)![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fecma-international.org%2Fpublications-and-standards%2Fstandards%2Fecma-262%2F "https://ecma-international.org/publications-and-standards/standards/ecma-262/")
  * [Webpack![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwebpack.js.org%2F "https://webpack.js.org/")
  * [Chart.js![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.chartjs.org%2Fdocs%2Flatest%2F "https://www.chartjs.org/docs/latest/")
  * [Tailwind CSS![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Ftailwindcss.com%2F "https://tailwindcss.com/")


**Note**
While our tutorials are framework-agnostic for ease of understanding, incorporating a framework such as Tailwind CSS or Vue.js can significantly decrease the amount of manual code needed for complex reports. We highly recommend exploring these frameworks to streamline your development process.
